# It's Android's first OpenOffice Document Reader!

This is a Python frontend for our C++ OpenDocument.core library. Feel free to use it in your own project too, but please don't forget to tell us about it!
